//[mahjong-utils](../../index.md)/[mahjongutils.models](index.md)/[toTilesString](to-tiles-string.md)

# toTilesString

[common]\
fun [Iterable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-iterable/index.html)&lt;[Tile](-tile/index.md)&gt;.[toTilesString](to-tiles-string.md)(lowercase: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = true): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)

将牌序列转换为牌文本

#### Return

牌的文本

#### Parameters

common

| | |
|---|---|
| lowercase | 牌种类字母是否使用小写字母 |
